@@ -1,4 +1,5 @@
 """Stats-utility functions for ArviZ."""
+
 import warnings
 from collections.abc import Sequence
 from copy import copy as _copy
@@ -134,7 +135,10 @@ def make_ufunc(
                 raise TypeError(msg)
         for idx in np.ndindex(out.shape[:n_dims_out]):
             arys_idx = [ary[idx].ravel() if ravel else ary[idx] for ary in arys]
-            out[idx] = np.asarray(func(*arys_idx, *args[n_input:], **kwargs))[index]
+            out_idx = np.asarray(func(*arys_idx, *args[n_input:], **kwargs))[index]
+            if n_dims_out is None:
+                out_idx = out_idx.item()
+            out[idx] = out_idx
         return out
 
     def _multi_ufunc(*args, out=None, out_shape=None, **kwargs):
